-- 装备转换 提示界面
Lua_EquipConvertWindow = class("Lua_EquipConvertWindow", Lua_Window);

function Lua_EquipConvertWindow:ctor()
    self:superCall("ctor");

    self.showBlackMask = true;
    self.isClickClose = true;
    
    self.windowName = "Lua_EquipConvertWindow";
    self.skinName ="EquipConvertWindow_skin";
end

function Lua_EquipConvertWindow:buildPanel(go)
    self:superCall("buildPanel", go);

    self:addLuaEvent("MONEY_UPDATE", self, self.onMoneyUpdate);
end

function Lua_EquipConvertWindow:buildShowItem()
    self:superCall("buildShowItem");

    self.showArr = Array();

    self.leftIcon = Lua_ItemIcon.new(self.content);
    self.leftIcon:setCanClick(true);
    self.leftIcon:setLocation(-160, 70, 0);

    self.rightIcon = Lua_ItemIcon.new(self.content);
    self.rightIcon:setCanClick(true);
    self.rightIcon:setLocation(160, 70, 0);

    self.leftBar.typeValue = 3;
    self.leftBar.fillMethodValue = 0;
    self.leftBar.fillOrigin = 0;

    self.rightBar.typeValue = 3;
    self.rightBar.fillMethodValue = 0;
    self.rightBar.fillOrigin = 0;

    self.sureBtn:addClickFuntion(self, self.onSureBtnClick);
    self.cancelBtn:addClickFuntion(self, self.onCancelBtnClick);
end

function Lua_EquipConvertWindow:dispose()
    if self.showArr ~= nil then
        self.showArr:dispose();
        self.showArr = nil;
    end
    if self.leftIcon ~= nil then
        self.leftIcon:dispose();
        self.leftIcon = nil;
    end
    if self.rightIcon ~= nil then
        self.rightIcon:dispose();
        self.rightIcon = nil;
    end
    self.data = nil;
    self:superCall("dispose");
end

function Lua_EquipConvertWindow:showWin(param)
    self:superCall("showWin", param);

    if param ~= nil then
        for i = 1, param:getSize() do
            self.showArr:add(param[i]);
        end

        if self.isFirst == nil then
            self.isFirst = true;
            self:updataShow();
        end
    else
        self:hide();
    end
end

function Lua_EquipConvertWindow:updataShow()
    if self.showArr:getSize() <= 0 then
        self:hide();
        return;
    end
    self.data = self.showArr:shift();

    local oldEquipVo = DataCenter.equipData:getEquipVoByUid(self.data.oldUid);
    if DataCenter.equipUtil:getEquipExp(oldEquipVo.equipLevelId) <= 0 then
        self.leftBar:setMaxValue(1);
        self.leftBar:setValue(0);
        self.leftBar:setText(LanUtil.getValue(126761));
    else
        local all_exp = DataCenter.equipUtil:getEquipUpgradeExp(oldEquipVo.equipLevelId);
        self.leftBar:setMaxValue(all_exp);
        self.leftBar:setValue(oldEquipVo.equipCurLevelExp);
        self.leftBar:setText(oldEquipVo.equipCurLevelExp.."/"..all_exp);
    end
    self.leftIcon:setData(oldEquipVo);
    self.leftIcon:showNum(0);

    local newEquipVo = DataCenter.equipData:getEquipVoByUid(self.data.newUid);
    local curExp, curLvl = DataCenter.equipUtil:getEquipStrongLevelAndLeftExp(newEquipVo.equipCurLevelExp, newEquipVo.equipLevelId, oldEquipVo.equipAllExp);
    local levelId = newEquipVo.id * 100 + curLvl;
    if DataCenter.equipUtil:getEquipExp(levelId) <= 0 then
        self.rightBar:setMaxValue(1);
        self.rightBar:setValue(0);
        self.rightBar:setText(LanUtil.getValue(126761));
    else
        local all_exp = DataCenter.equipUtil:getEquipUpgradeExp(levelId);
        self.rightBar:setMaxValue(all_exp);
        self.rightBar:setValue(curExp);
        self.rightBar:setText(curExp.."/"..all_exp);
    end

    local itemVo = Lua_ToolVo.createToolVo(newEquipVo.id);
    itemVo.equipLevel = curLvl;
    itemVo.equipScore = DataCenter.equipUtil:getLvlSocre(itemVo.equipLevelId, itemVo.score);

    self.rightIcon:setData(itemVo);
    self.rightIcon:showNum(0);

    self:onMoneyUpdate();
end

function Lua_EquipConvertWindow:onMoneyUpdate(dic)
    if self.data == nil or (dic ~= nil and dic[Lua_ResourcesDefine.GOLD] == nil) then
        return;
    end

    self.costMoney = DataCenter.equipData:getEquipConvertCost(self.data.oldUid, self.data.newUid);
    local packNum = DataCenter.moneyData:getMoney(Lua_ResourcesDefine.GOLD);
    local colorStr = "FFFFFF";
    if self.costMoney > packNum then
        colorStr = "ee2c24";
    end
    self.costTxt.text = Lua_ColorDefine.getColorStr(colorStr, numberTrans(self.costMoney).."/"..numberTrans(packNum));
    self.costTxt:resetSize();

    local width = self.costTxt.width;
    if width < 160 then
        width = 160;
    end
    self.costBg:SetDimensions(205.5 + (width - 160), 36);
    self.costIcon:setLocation(70.4 - (width - 160) / 2, -106.3, 0);
end

function Lua_EquipConvertWindow:onSureBtnClick()
    if self.clickTime and getTime() - self.clickTime <= 0.2 then
        OperateAlert.showLangValue(126798);
        return;
    end
    self.clickTime = getTime();

    if DataCenter.moneyData:isMoneyEnough(Lua_ResourcesDefine.GOLD, self.costMoney, true, true, false) then
        local newEquipVo = DataCenter.equipData:getEquipVoByUid(self.data.newUid);
        local oldEquipVo = DataCenter.equipData:getEquipVoByUid(self.data.oldUid);
        Lua_ProxyManager.getProxy("Lua_EquipProxy"):sEquipConvert(newEquipVo.hero_uid, self.data.newUid, self.data.oldUid, oldEquipVo.hero_uid);
        OperateAlert.showLangValue(126799);

        self:updataShow();
    end
end

function Lua_EquipConvertWindow:onCancelBtnClick()
    self:updataShow();
end