-- 灵符合成 Panel
Lua_CharmCompoundPanel = class("Lua_CharmCompoundPanel", Lua_DisplayObject);

function Lua_CharmCompoundPanel:ctor(p)
	self:superCall("ctor", p, "CharmCompoundPanel_skin");
end

function Lua_CharmCompoundPanel:buildPanel()
	self:superCall("buildPanel");
    self:addLuaEvent("UPDATE_CHARM_COMPOUND", self, self.onCompoundResult);

    self:addLuaEvent("CHARM_COMPOUND_ITEM_SELECT", self, self.updateSelectItem);
end

function Lua_CharmCompoundPanel:buildShowItem()
	self:superCall("buildShowItem");

    self.selectUidArr = Array();

    local posList = {{-151, 41}, {-1, 498}, {146, 41}};
    self.showItemList = Array();
    local item;
    for i = 1, #posList do
        item = Lua_CharmCompoundItem.new(self.content);
        item:setLocation(posList[i][1], posList[i][2]);
        self.showItemList:add(item);
    end

    self.dragList = Lua_DragList.new(self.content, 620, 225, Lua_AxisDefine.Vertical);
    self.dragList.customParam = self.selectUidArr;
    self.dragList:setListCell(Lua_CharmCompoundSelectItem, 120, 120, 5);
    self.dragList:setCellSpacing(5, 5);
    self.dragList:setLocation(0, -405);

    local btnInfoArr = Array();
    btnInfoArr:add({textStr = "全", color = 0});
    btnInfoArr:add({textStr = "紫", color = 4});
    btnInfoArr:add({textStr = "橙", color = 5});
    btnInfoArr:add({textStr = "红", color = 6});
    btnInfoArr:add({textStr = "彩", color = 7});

    self.btnList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
    self.btnList:setLocation(0, -565, 0);
    self.btnList:setButtonStyle("common_altas_1", "xui_common_button_006_n", "xui_common_button_006_n", 150, 56, 0.01, 1);
    self.btnList:setButtonText(0, 1, "594d4d", "8f5123", 28, 28, Lua_MyUISettings.huakangFontName, UnityEngine.FontStyle.Normal);
    self.btnList:setButtonItem(130, 56);
    self.btnList:setClickCallBack(self, self.onBtnClick);
    self.btnList:setData(btnInfoArr);
    self.btnList:setSelected(1);

    self.tipBtn:addClickFuntion(self, self.onTipBtnClick);
    self.skillBtn:addClickFuntion(self, self.onSkillBtnClick);
    self.oneKeyBtn:addClickFuntion(self, self.onOneKeyBtnClick);
    self.compoundBtn:addClickFuntion(self, self.onCompoundBtnClick);
    self.addBtn:addClickFuntion(self, self.onAddBtnClick);

    self.itemIcon.clickScale = false;
    self.itemIcon:addClickFuntion(self, self.onItemIconClick);
end

function Lua_CharmCompoundPanel:dispose()
    if self.showItemList ~= nil then
        self.showItemList:dispose();
        self.showItemList = nil;
    end
    if self.dragList ~= nil then
        self.dragList:dispose();
        self.dragList = nil;
    end
    if self.btnList ~= nil then
        self.btnList:dispose();
        self.btnList = nil;
    end
    if self.selectUidArr ~= nil then
        self.selectUidArr:dispose();
        self.selectUidArr = nil;
    end
    if self.showEffArr ~= nil then
        self.showEffArr:dispose();
        self.showEffArr = nil;
    end
	self:superCall("dispose")
end

function Lua_CharmCompoundPanel:onBtnClick(idx, data)
    self.color = data.color;
    self:updateSelect();
end

function Lua_CharmCompoundPanel:updateSelect()
    local arr = DataCenter.heroCharmData:getCompoundCharmVoArr(self.color);
    self.dragList:setArrayData(arr);
end

function Lua_CharmCompoundPanel:updateSelectItem(itemVo)
    local uid = itemVo.unique_id;
    local isSelect = self.selectUidArr:indexOf(uid) ~= -1;
    if isSelect then
        self.selectUidArr:removeItem(uid);
    else
        local len = self.selectUidArr:getSize();
        if len >= 3 then
            OperateAlert.show("材料已选满");
            return;
        elseif self.selectVo ~= nil then
            if self.selectVo.color ~= itemVo.color then
                OperateAlert.show("材料需品质一致");
                return;
            end
        end
        self.selectUidArr:add(uid);
    end
    self:updateData();
    self.dragList:updateShowList();
end

function Lua_CharmCompoundPanel:updateData()
    local isSelect = self.selectUidArr:getSize() > 0;
    if isSelect then
        self.selectVo = DataCenter.packData:getItemVoByUnId(self.selectUidArr[1]);
        self.nextItemVo = Lua_ToolVo.createToolVo(self.selectVo.next_item_id);
        self.nextItemVo.level = self.nextItemVo.max_level;

        self.itemBg:setAltas("rune_atlas", "xui_fs_bg_0" .. (11 - self.nextItemVo.color));
        self.itemIcon:setAltas(self.nextItemVo.atlas, self.nextItemVo.sprite);

        local costList = self.selectVo.made_cost;
        self.costTxt.text = DataCenter.packData:getItemCountById(costList[1][1]);
    else
        self.selectVo = nil;
        self.nextItemVo = nil;
        self.costTxt.text = "0";
    end
    self.itemBg:setEnable(isSelect);
    self.itemIcon:setEnable(isSelect);

    for i = 1, self.showItemList:getSize() do
        self.showItemList[i]:setData(self.selectUidArr[i]);
    end
end

function Lua_CharmCompoundPanel:onCompoundResult()
    self.selectUidArr:clear();
    self:updateSelect();
    self:updateData();
end

function Lua_CharmCompoundPanel:onTipBtnClick()
    local param = {des = "", posX = 175, posY = -300};
    Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, param);
end

function Lua_CharmCompoundPanel:onSkillBtnClick()
    Lua_WindowUtil.openWin("Lua_HeroCharmSkillShowWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_CharmCompoundPanel:onOneKeyBtnClick()
    local arr = DataCenter.heroCharmData:getOneKeyCharmVoArr();
    if arr ~= nil then
        self.selectUidArr:clear();
        for i = 1, arr:getSize() do
            self.selectUidArr:add(arr[i]);
        end
        self:updateData();
        self.dragList:updateShowList();
    else
        OperateAlert.show("合成材料不足");
    end
end

function Lua_CharmCompoundPanel:onCompoundBtnClick()
    if self.selectUidArr:getSize() == 3 then
        local costId = DataCenter.packData:checkConsumeEnough(self.selectVo.made_cost);
        if costId == nil then
            self:showItemEff();
        else
            DataCenter.packUtil:openPathWindow(costId);
        end
    else
        OperateAlert.show("合成数量不足");
    end
end

function Lua_CharmCompoundPanel:onAddBtnClick()
    if self.selectVo ~= nil then
        local costList = self.selectVo.made_cost;
        DataCenter.packUtil:openPathWindow(costList[1][1], false);
    end
end

function Lua_CharmCompoundPanel:onItemIconClick()
    if self.nextItemVo ~= nil then
        Lua_WindowUtil.openWin("Lua_HeroCharmTipWindow", Lua_WinParam.ACTION_OPEN, {data = self.nextItemVo, isShowBtns = false});
    end
end

function Lua_CharmCompoundPanel:showItemEff()
    if self.showEffArr == nil then
        self.showEffArr = Array();
    end
    self.isShowEff = true;

    local item;
    local nameStr;
    for i = 1, 3 do
        item = self.showEffArr[i];
        if item == nil then
            nameStr = "ui_zb_fshc_0" .. (2 * i - 1)
            item = UICreate.createUIEffect(self.content, "/effects/uiEffects/" .. nameStr, nameStr, 0, 0);
            self.showEffArr:add(item);
        else
            item:setEnable(false);
            item:setEnable(true);
        end
    end
    self:addTimer("showEndEff", 1, self, self.showEndEff, nil, 1);
end

function Lua_CharmCompoundPanel:showEndEff()
    if self.showEff == nil then
        self.showEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_zb_fshc_06", "ui_zb_fshc_06", 0, 0);
    else
        self.showEff:setEnable(false);
        self.showEff:setEnable(true); 
    end
    self:addTimer("onSureFun", 0.5, self, self.onSureFun, nil, 1);
end

function Lua_CharmCompoundPanel:onSureFun()
    Lua_ProxyManager.getProxy("Lua_HeroCharmProxy"):sCharmSkillCompound(self.selectUidArr);
end































Lua_CharmCompoundItem = class("Lua_CharmCompoundItem", Lua_DisplayObject);

function Lua_CharmCompoundItem:ctor(p)
    self:superCall("ctor", p, "CharmCompoundItem_skin");
end

function Lua_CharmCompoundItem:buildShowItem()
    self:superCall("buildShowItem");

    self.bg:addClickFuntion(self, self.onBgClick);
end

function Lua_CharmCompoundItem:dispose()
    self.data = nil;
    self:superCall("dispose");
end

function Lua_CharmCompoundItem:setData(uid)
    self.uid = uid;
    if uid ~= nil then
        self.data = DataCenter.packData:getItemVoByUnId(uid);
        self.icon:setAltas(self.data.atlas, self.data.sprite);
    else
        self.data = nil;
    end
    self.addIcon:setEnable(uid == nil);
    self.showIcon:setEnable(uid ~= nil);
    self.icon:setEnable(uid ~= nil);
end

function Lua_CharmCompoundItem:onBgClick()
    if self.data == nil then return end
    DataCenter.packUtil:showItemInfo(self.data);
end























Lua_CharmCompoundSelectItem = class("Lua_CharmCompoundSelectItem", Lua_ItemIconCell);

function Lua_CharmCompoundSelectItem:buildShowItem()
    self:superCall("buildShowItem");
end

function Lua_CharmCompoundSelectItem:setCustomParam(customParam)
    self.selectUidArr = customParam;
end

function Lua_CharmCompoundSelectItem:setData(data)
    self:superCall("setData", data);
    self:updateData();
end

function Lua_CharmCompoundSelectItem:updateData()
    local isSelect = self.selectUidArr:indexOf(self.data.unique_id) ~= -1;
    self.itemIcon:setDrawMask(isSelect);
end

function Lua_CharmCompoundSelectItem:onPressClick()
    Lua_MsgUtil.callFunc("CHARM_COMPOUND_ITEM_SELECT", self.data);
end

function Lua_CharmCompoundSelectItem:onLongPressClick()
    if self.data == nil then
        return;
    end
    DataCenter.packUtil:showItemInfo(self.data);
end