--符文重铸
Lua_RunesRecastWindow = class("Lua_RunesRecastWindow", Lua_Window);
function Lua_RunesRecastWindow:ctor()
    self:superCall("ctor");
    self.showBlackMask = true;
    self.isClickClose = true;
    self.windowName = "Lua_RunesRecastWindow";
    self.skinName = "RunesRecastWindow_skin";
end

function Lua_RunesRecastWindow:buildShowItem()
    self:superCall("buildShowItem");
    self.barObj:SetActive(false);

    self.itemIcon = Lua_ItemIcon.new(self.content);
    self.itemIcon:setLocation(0, 347, 0);
    self.itemIcon:setClick(self, self.onItemClick);

  	self.checkHelp_1:addClickFuntion(self, self.onHelpClick1);
    self.checkHelp_2:addClickFuntion(self, self.onHelpClick2);
    self.recast_btn:addClickFuntion(self, self.onRecastBtnClick);
    self.save_btn:addClickFuntion(self, self.onSaveBtnClick);

    self:addLuaEvent("RECAST_NUM", self, self.showBar); -- 重铸次数返回
    self:addLuaEvent("RECAST_SAVE", self, self.updateRecastInfo); -- 重铸保存
    self:addLuaEvent("RECAST_SURE", self, self.recastReturnInfo); -- 重铸返回

    self:addLuaEvent("MONEY_UPDATE", self, self.onItemUpdate);
    self:addLuaEvent("PACK_ITEMS_UPDATE", self, self.onItemUpdate);

    Lua_WindowUtil.openWin("Lua_RunesTipsWindow", Lua_WinParam.ACTION_CLOSE);
end

function Lua_RunesRecastWindow:showWin(data)
    self:superCall("showWin", data);

    self.itemIcon:setData(data);
    self.itemIcon:showNum(0);
    self.nameText.text = data.colorName;
    
    if data.color >= DataCenter.runesUtil.recast_bar_limit then
        self.show_num = 0;
        self.max_value = DataCenter.runesUtil:getRecastConfigInfo(data.color).guarantee_num; --幸运次数上限
    	Lua_ProxyManager.getProxy("Lua_RunesProxy"):sRecastNum(data.color);
    else
        self.barObj:SetActive(false);
    end
    self:updateRecastInfo(data);
end

function Lua_RunesRecastWindow:updateRecastInfo(data)
    if type(data) == "number" then
    	data = DataCenter.runesData:getRunesVoByUid(data);
    end
    self.data = data;
    
    self:showAttrL(data.cur_prop);
    if #data.rune_skill_list > 0 then
        self:showTips(false);
    	self:showSkillL(data.rune_skill_list);
    else
        self:showTips(true);
    end
    
    self:showCost();
    self:recastReturnInfo(data)
end

--重铸更新
function Lua_RunesRecastWindow:recastReturnInfo(data)
    if type(data) == "number" then
        data = DataCenter.runesData:getRunesVoByUid(data);
    end
	self:showAttrR(data.recast_prop);
	if #self.data.rune_skill_list > 0 then
		self:showSkillR(data.recast_skill_list);
	end

    local bool = #data.recast_prop > 0;
    self:updateBtnChange(bool);
end

function Lua_RunesRecastWindow:showTips(bShow)
    if bShow then
        if self.arrowIcon ~= nil then
            self.arrowIcon:setEnable(false);
        end

        if self.noneIcon == nil then
            self.noneIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "xui_common_widget_012", 0, -122, 0, 0);
            self.noneIcon:setScale(0.8, 0.8, 0.8);
        end
        self.noneIcon:setEnable(true);

        if self.noneText == nil then
            self.noneText = UICreate.createLabel(self.content, LanUtil.getValue(126809), 0, -152, 100, 50, 36);
            self.noneText.pivot = UIUtils.Pivot.Center;
            self.noneText.fontName = Lua_MyUISettings.huakangFontName;
            self.noneText.alignmentValue = 4;
            self.noneText.horizontalOverflowValue = 1;
            self.noneText.colorStr = Lua_ColorDefine.transColorStr("938680");
        end
        self.noneText:setEnable(true);
    else
        if self.arrowIcon == nil then
            self.arrowIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "xui_common_label_22", 0, -176, 0, 0);
        end
        self.arrowIcon:setEnable(true);

        if self.noneIcon ~= nil then
            self.noneIcon:setEnable(false);
        end
        if self.noneText ~= nil then
            self.noneText:setEnable(false);
        end
    end

    self.left_bg:setEnable(not bShow);
    self.right_bg:setEnable(not bShow);
end

--更新按钮状态
function Lua_RunesRecastWindow:updateBtnChange(bool)
    if bool == true then
        self.recast_btn:setStyle(3);
        self.recast_btn:setLocation(-164, -447, 0);
    else
        self.recast_btn:setStyle(1);
        self.recast_btn:setLocation(0, -447, 0);
    end
    self.save_btn:setEnable(bool);
end

--进度条
function Lua_RunesRecastWindow:showBar(num)
    if self.max_value == nil then
        return;
    end

    self.show_num = num;
	self.recastBar:setText(num.."/"..self.max_value);
    self.recastBar:setMaxValue(self.max_value);
    self.recastBar:setValue(num);
    self.barObj:SetActive(true);
    self:showDis();
end

--重铸次数描述
function Lua_RunesRecastWindow:showDis()
    local value = self.max_value - self.show_num;
    self.isLuckyRecast = value <= 0;
    if not self.isLuckyRecast then
        self.des.text = LanUtil.formateStr(126810, tostring(value));
        self.recast_btn:setLangValue(126839);
    else
        self.des:setLangValue(126811);
        self.recast_btn:setLangValue(126840);
    end
end

-- 基础属性
function Lua_RunesRecastWindow:showAttrL(list)
    local arr = DataCenter.attributesUtil:getAttrArrByServer(list);
    if self.attrLArr == nil then
        self.attrLArr = Array();
    end
    self.baseAttrLen = arr:getSize();
    local len = self.attrLArr:getSize();
    local maxLen = self.baseAttrLen > len and self.baseAttrLen or len;
    local item;
    for i = 1, maxLen do
        item = self.attrLArr[i];
        if i > self.baseAttrLen then
            if item ~= nil then
                item:setEnable(false);
            end
        else
            if item == nil then
                item = Lua_RunesRecastAttrItem.new(self.content);
                self.attrLArr:add(item);
            else
                item:setEnable(true);
            end
            item:setLocation(0, 133 - (i - 1) * 44, 0);
            item:setData(arr[i]);
        end
    end
end

-- 重铸属性
function Lua_RunesRecastWindow:showAttrR(list)
    local arr = DataCenter.attributesUtil:getAttrArrByServer(list);
    if self.attrRArr == nil then
        self.attrRArr = Array();
        self.attrREffArr = Array();
    end
    local dataLen = arr:getSize();
    dataLen = dataLen == 0 and self.baseAttrLen or dataLen;
    local len = self.attrRArr:getSize();
    local maxLen = dataLen > len and dataLen or len;
    local item;
    local eff;
    for i = 1, maxLen do
        item = self.attrRArr[i];
        eff = self.attrREffArr[i];
        if i > dataLen then
            if item ~= nil then
                item:setEnable(false);
            end
        else
            if item == nil then
                item = Lua_AttrIconItem.new(self.content);
                item:setTextStyle(nil, nil, "469254")
                item.pivot = -1;
                item.spacingX = -7.5;
                self.attrRArr:add(item);
            else
                item:setEnable(true);
            end
            item:setLocation(223, 133 - (i - 1) * 44, 0);

            if arr[i] == nil then
                if eff ~= nil then
                    eff:setEnable(false);
                end
                item:setData(nil, nil, LanUtil.getValue(126808));
            else
                if self.bRecast then
                    if eff == nil then
                       eff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_zb_cz_01", "ui_zb_cz_01", 146, 132 - (i - 1) * 44);
                       self.attrREffArr:add(eff);
                    end
                    eff:setEnable(false);
                    eff:setEnable(true);
                end
                item:setData("common_altas_2", arr[i].attr_icon_2, Lua_ColorDefine.getColorStr("7E6560",arr[i].show_name).."+"..arr[i].showValue);
            end
        end
    end
    self.bRecast = false;
end

-- 技能
function Lua_RunesRecastWindow:showSkillL(list)
	local arr = DataCenter.runesUtil:getSkillArrByServer(list);
    if self.skillLArr == nil then
        self.skillLArr = Array();
    end
    self.skillLen = arr:getSize();
    local len = self.skillLArr:getSize();
    local maxLen = self.skillLen > len and self.skillLen or len;
    local item;
    for i = 1, maxLen do
        item = self.skillLArr[i];
        if i > self.skillLen then
            if item ~= nil then
                item:setEnable(false);
            end
        else
            if item == nil then
                item = Lua_RunesRecastSkillItem.new(self.content);
                self.skillLArr:add(item);
            else
                item:setEnable(true);
            end
            item:setLocation(-164, -85 - (i - 1) * 136, 0);
            item:setData(arr[i]);
        end
    end
end

-- 技能
function Lua_RunesRecastWindow:showSkillR(list)
	local arr = DataCenter.runesUtil:getSkillArrByServer(list);
    if self.skillRArr == nil then
        self.skillRArr = Array();
    end

    local dataLen = arr:getSize();
    dataLen = dataLen == 0 and self.skillLen or dataLen;

    local bEffect = false;
    if self.skill_num ~= nil and self.skill_num ~= dataLen then
        bEffect = dataLen > 1;
    end
    self.skill_num = dataLen;

    local len = self.skillRArr:getSize();
    local maxLen = dataLen > len and dataLen or len;
    local item;
    for i = 1, maxLen do
        item = self.skillRArr[i];
        if i > dataLen then
            if item ~= nil then
                item:setEnable(false);
                item.old_lvl = nil;
            end
        else
            if item == nil then
                item = Lua_RunesRecastSkillItem.new(self.content,1);
                self.skillRArr:add(item);
            else
                item:setEnable(true);
                item:showEffect(false);
            end
            item:setLocation(164, -85 - (i - 1) * 136, 0);
            item:setData(arr[i]);
            if i > 1 and bEffect then
                item:showEffect(true);--技能多了一个
            end
        end
    end
end

--材料展示
function Lua_RunesRecastWindow:showCost()
    self.costInfo = DataCenter.runesUtil:getCostItemInfo(self.data.recast_cost_items);
    if self.costArr == nil then
        self.costArr = Array();
    end

    local dataLen = self.costInfo:getSize();
    local len = self.costArr:getSize();
    local maxLen = dataLen > len and dataLen or len;
    local item;
    local startX = -141;
    local perWidth = 337;
    for i = 1, maxLen do
        item = self.costArr[i];
        if i > dataLen then
            if item ~= nil then
                item:setEnable(false);
            end
        else
            if item == nil then
                item = Lua_RunesRecastCostItem.new(self.content);
                self.costArr:add(item);
            else
                item:setEnable(true);
            end
            item:setLocation(startX + (i - 1) * perWidth, -496, 0);
            item:setData(self.costInfo[i]);
        end
    end
end

function Lua_RunesRecastWindow:onItemUpdate(dic)
    if self.costInfo == nil or dic == nil then return end
    
    for i = 1, self.costInfo:getSize() do
        if dic[self.costInfo[i].id] ~= nil then
            self:showCost();
            break;
        end
    end
end

--重铸
function Lua_RunesRecastWindow:onRecastBtnClick()

    if self.isLuckyRecast then --幸运重铸
        Lua_WindowUtil.openWin("Lua_RunesLuckyRecastWindow", Lua_WinParam.ACTION_OPEN, self.data);
    else
        local costId = DataCenter.runesUtil:isHaveMeetCost(self.costInfo);
        if costId ~= nil then
            DataCenter.packUtil:openPathWindow(costId, false);
            return;
        end
        self.bRecast = true;
        Lua_ProxyManager.getProxy("Lua_RunesProxy"):sRecastRunes(self.data.unique_id, 0,self.data.hero_uid);
    end
end

--保存
function Lua_RunesRecastWindow:onSaveBtnClick()
    Lua_ProxyManager.getProxy("Lua_RunesProxy"):sSaveRecastResult(self.data.unique_id,self.data.hero_uid);
end

function Lua_RunesRecastWindow:onItemClick()
    Lua_WindowUtil.openWin("Lua_RunesRecastSkillDesWindow", Lua_WinParam.ACTION_OPEN, self.data);
end

function Lua_RunesRecastWindow:onHelpClick1(go)
	local tipsData = { des = LanUtil.getValue(126807), posX = 185, posY = 340, needAdapt = false; };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_RunesRecastWindow:onHelpClick2(go)
    Lua_WindowUtil.openWin("Lua_RunesSkillShowWindow", Lua_WinParam.ACTION_OPEN, self.data.color);
end

function Lua_RunesRecastWindow:dispose()
	if self.attrLArr ~= nil then
        self.attrLArr:dispose();
        self.attrLArr:clear();
        self.attrLArr = nil;
    end
    if self.attrRArr ~= nil then
        self.attrRArr:dispose();
        self.attrRArr:clear();
        self.attrRArr = nil;
    end
    if self.attrREffArr ~= nil then
        self.attrREffArr:dispose();
        self.attrREffArr:clear();
        self.attrREffArr = nil;
    end
    if self.skillLArr ~= nil then
        self.skillLArr:dispose();
        self.skillLArr:clear();
        self.skillLArr = nil;
    end
    if self.skillRArr ~= nil then
        self.skillRArr:dispose();
        self.skillRArr:clear();
        self.skillRArr = nil;
    end
    if self.costArr ~= nil then
        self.costArr:dispose();
        self.costArr:clear();
        self.costArr = nil;
    end
    if self.itemIcon ~= nil then
        self.itemIcon:dispose();
        self.itemIcon = nil;
    end
    self.noneText = nil;
    self.noneIcon = nil;
    self.arrowIcon = nil;
    self.data = nil;
    self:superCall("dispose");
end










--重铸属性
Lua_RunesRecastAttrItem = class("Lua_RunesRecastAttrItem", Lua_DisplayObject);
function Lua_RunesRecastAttrItem:ctor(p)
    self:superCall("ctor", p, "RunesRecastAttrItem_skin");
end

function Lua_RunesRecastAttrItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_RunesRecastAttrItem:setData(data)
    self.attrIcon:setAltas("common_altas_2", data.attr_icon_2);
    self.attrText.text = data.show_name..Lua_ColorDefine.getColorStr("469254", "+"..data.showValue);
end

function Lua_RunesRecastAttrItem:dispose()
	self:superCall("dispose");
end











--符石技能
Lua_RunesRecastSkillItem = class("Lua_RunesRecastSkillItem", Lua_DisplayObject);
function Lua_RunesRecastSkillItem:ctor(p, typev)
    self.typev = typev;--1
    self:superCall("ctor", p, "RunesRecastSkillItem_skin");
end

function Lua_RunesRecastSkillItem:buildShowItem()
	self:superCall("buildShowItem");
    self.skill_icon = Lua_SkillIconItem.new(self.content);
    self.skill_icon:setBgAlpha(0.5);
    self.skill_icon:setSiblingIndex(0);
end

function Lua_RunesRecastSkillItem:dispose()
    self.data = nil;
    if self.eff ~= nil then
        self.eff:dispose();
        self.eff = nil;
    end
    if self.skill_icon ~= nil then
        self.skill_icon:dispose();
        self.skill_icon = nil;
    end
    self:superCall("dispose");
end

function Lua_RunesRecastSkillItem:setData(data)
    self.data = data;
    if data == nil then
        self.skill_icon:setCanClick(false);
        self.skill_icon:setData(nil);
        self.skill_icon:setRarityIcon(nil);

        self.mask:setEnable(true);
        self.nameText:setLangValue(126818);
        self:showEffect(false);
        self.old_lvl = 0;
    else
        self.skill_icon:setCanClick(true);
        self.skill_icon:setData(data);
        self.skill_icon:setRarityIcon(data.rarity);

        self.mask:setEnable(false);
        self.nameText.text = data.name;
        if self.typev == 1 and self.old_lvl ~= nil and self.old_lvl ~= self.data.skillId then
            self:showEffect(true);
        else
            self:showEffect(false);
        end
        self.old_lvl = self.data.skillId;
    end
end

--技能改变特效
function Lua_RunesRecastSkillItem:showEffect(bool)
    if bool then
        if self.eff == nil then
            self.eff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_fs_cz_01", "ui_fs_cz_01", 0, 0);
        end
        self.bUpLevel = nil;
        self.eff:setEnable(false);
        self.eff:setEnable(true);
    else
        if self.eff ~= nil then
            self.eff:setEnable(false);
        end
    end
end

function Lua_RunesRecastSkillItem:onBtnClick()
    if self.data ~= nil then
        Lua_WindowUtil.openWin("Lua_SkillTipsWindow", Lua_WinParam.ACTION_OPEN, self.data);
    end
end










-- 符文重铸消耗item
Lua_RunesRecastCostItem = class("Lua_RunesRecastCostItem", Lua_DisplayObject);
function Lua_RunesRecastCostItem:ctor(p)
    self:superCall("ctor", p, "RunesRecastCostItem_skin");
end

function Lua_RunesRecastCostItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_RunesRecastCostItem:dispose()
    self.data = nil;
    self:superCall("dispose");
end

function Lua_RunesRecastCostItem:setData(data)
	local tvo = Lua_ToolVo.new(data.id);
    self.icon:setAltas(tvo.iconAtlas, tvo.iconSprite);

	local need_num = data.need_num;
	local bagNum = DataCenter.packData:getItemCountById(data.id);
    if bagNum < need_num then
        bagNum = Lua_ColorDefine.getColorStr("ed4b2e", numberTrans(bagNum));
    else
        bagNum = Lua_ColorDefine.getColorStr("469254", numberTrans(bagNum));
    end
    self.value.text = bagNum.."/"..numberTrans(need_num);
    self.value:resetSize();
    self.icon:setLocation(-self.value.width/2-30,0,0)
end