-- 战法附魂 Panel
Lua_TacticConnectPanel = class("Lua_TacticConnectPanel", Lua_TacticDevelopBasePanel);

function Lua_TacticConnectPanel:ctor(p)
    self:superCall("ctor", p, "TacticConnectPanel_skin");
end

function Lua_TacticConnectPanel:buildPanel()
    self:superCall("buildPanel");
    self:addLuaEvent("UPDATE_TACTIC_INFO", self, self.updateData);
end

function Lua_TacticConnectPanel:buildShowItem()
    self:superCall("buildShowItem");

    self.propItemArr = Array();

    self.ratioVal = DataCenter.heroTacticUtil.inherit_rate;
    self.tipTxt.text = LanUtil.formateStr(792022, self.ratioVal * 100);

    self.tipBtn:addClickFuntion(self, self.onTipBtnClick);
    self.addIcon:addClickFuntion(self, self.onChangeBtnClick);
    self.changeBtn:addClickFuntion(self, self.onChangeBtnClick);
    self.mainBg:addClickFuntion(self, self.onMainBgClick);
    self.subBg:addClickFuntion(self, self.onSubBgClick);
end

function Lua_TacticConnectPanel:dispose()
    if self.propItemArr ~= nil then
        self.propItemArr:dispose();
        self.propItemArr = nil;
    end
    if self.mainEff ~= nil then
        self.mainEff:dispose();
        self.mainEff = nil;
    end
    if self.subEff ~= nil then
        self.subEff:dispose();
        self.subEff = nil;
    end
    self:superCall("dispose");
end

function Lua_TacticConnectPanel:setData(tacticId)
    self.tacticId = tacticId;
    self:updateData();
end

function Lua_TacticConnectPanel:updateData()
    local data = DataCenter.heroTacticData:getTacticVo(self.tacticId);
    self.titleTxt.text = data.tacticName;

    local isChild = data.tacticAttachId > 0;
    local isAdd;
    if isChild then
        isAdd = true;
        self.mainTacticVo = DataCenter.packData:getItemVoByUnId(data.tacticAttachId);
        self.subTacticVo = data;

        self:showSubEff(data);
        self.changeBtn:setLangValue(792023);

        self.addTxt.text = LanUtil.formateStr(792025, self.mainTacticVo.tacticColorName);
    else
        isAdd = data.tacticInheritId > 0;
        self.mainTacticVo = data;

        if isAdd then
            self.subTacticVo = DataCenter.packData:getItemVoByUnId(data.tacticInheritId);
            self:showSubEff(self.subTacticVo);
        end
        self.changeBtn:setLangValue(792024);

        self.addTxt:setLangValue(792026);
    end
    self.addObj:SetActive(isAdd);
    self.addIcon:setEnable(not isAdd);
    self.tipTxt:setEnable(not isAdd);

    self:showMainEff(self.mainTacticVo);

    self.addTxt:resetSize();
    local addWidth = self.addTxt.width - 196;
    if addWidth < 0 then
        addWidth = 0;
    end
    self.lline1:setLocation(-205 - addWidth / 2, 352.5, 0);
    self.lline2:setLocation(205 + addWidth / 2, 352.5, 0);

    if isAdd then
        local arr = self.subTacticVo.showPropArr;
        local len = arr:getSize();
        local num = self.propItemArr:getSize();
        local count = len > num and len or num;
        local item;
        local attrVo;
        for i = 1, count do
            item = self.propItemArr[i];
            if item == nil then
                item = Lua_TacticAttributeItem.new(self.addObj, 3);
                item:setRectAnchor(7);
                item:setLocation(-285 + (i - 1) % 2 * 350, 290 - Mathf.Floor((i - 1) / 2) * 40, 0);
                self.propItemArr:add(item);
            end

            if len >= i then
                attrVo = arr[i];
                attrVo.value = attrVo.value * self.ratioVal;
                item:setData(attrVo);
            end
            item:setEnable(len >= i);
        end
    end

    self:showStar(data.star, data.max_star);
end

function Lua_TacticConnectPanel:onTipBtnClick()
    local tipData = {des = LanUtil.getValue(792027), posX = -140, posY = -300};
    Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_TacticConnectPanel:onChangeBtnClick()
    local tacticHeroUid = self.mainTacticVo.tacticHeroUid;
    if tacticHeroUid == nil or tacticHeroUid <= 0 then
        OperateAlert.showLangValue(792028);
        return;
    end

    if self.mainTacticVo.id ~= self.tacticId then
        Lua_ProxyManager.getProxy("Lua_HeroTacticProxy"):sTacticAttach(self.mainTacticVo.unique_id);
    else
        Lua_WindowUtil.openWin("Lua_TacticSelectWindow", Lua_WinParam.ACTION_OPEN, {selectType = 2, heroUid = tacticHeroUid, tacticUid = self.mainTacticVo.unique_id});
    end
end

function Lua_TacticConnectPanel:onMainBgClick()
    if self.mainTacticVo.id == self.tacticId then
        return;
    end
    Lua_WindowUtil.openWin("Lua_TacticDevelopWindow", Lua_WinParam.ACTION_OPEN, {tacticId = self.mainTacticVo.id, index = 1});
end

function Lua_TacticConnectPanel:onSubBgClick()
    if self.mainTacticVo.id ~= self.tacticId then
        return;
    end
    Lua_WindowUtil.openWin("Lua_TacticDevelopWindow", Lua_WinParam.ACTION_OPEN, {tacticId = self.subTacticVo.id, index = 1});
end

function Lua_TacticConnectPanel:showMainEff(tacticVo)
    if self.mainEff == nil then
        self.mainEff = UICreate.createUIEffect(self.content, tacticVo.effect_path, tacticVo.effect_name, 0, 0);
        self.mainEff.anchorValue = 1;
        self.mainEff.siblingIndex = 5;
    else
        self.mainEff:setUrl(tacticVo.effect_path, tacticVo.effect_name);
    end

    local scale = tacticVo.main_spine_scale;
    local offset = tacticVo.main_spine_offset;
    self.mainEff:setScale(scale, scale, scale);
    self.mainEff:setLocation(-185 + offset[1], -845 + offset[2]);
end

function Lua_TacticConnectPanel:showSubEff(tacticVo)
    if self.subEff == nil then
        self.subEff = UICreate.createUIEffect(self.addObj,tacticVo.effect_path, tacticVo.effect_name, 0, 0);
        self.subEff.anchorValue = 1;
        self.subEff.siblingIndex = 1;
    else
        self.subEff:setUrl(tacticVo.effect_path, tacticVo.effect_name);
    end

    local scale = tacticVo.sub_spine_scale;
    local offset = tacticVo.sub_spine_offset;
    self.subEff:setScale(scale, scale, scale);
    self.subEff:setLocation(210 + offset[1], -795 + offset[2]);
end