-- 战法羁绊 Panel
Lua_TacticFetterPanel = class("Lua_TacticFetterPanel", Lua_DisplayObject);

function Lua_TacticFetterPanel:ctor(p)
    self:superCall("ctor", p, "TacticFetterPanel_skin");
end

function Lua_TacticFetterPanel:buildPanel()
    self:superCall("buildPanel");
    self:addLuaEvent("UPDATE_TACTIC_FETTER_INFO", self, self.updateData);
    self:addLuaEvent("UPDATE_TACTIC_INFO", self, self.updateData);
end

function Lua_TacticFetterPanel:buildShowItem()
    self:superCall("buildShowItem");

    self.dragContainer = Lua_DragContainer.new(self.content, 670, 1080 + self.adaptHeight, Lua_AxisDefine.Vertical);
    self.dragContainer:setCellSpacing(0, 15);
    self.dragContainer:setLocation(0, -55, 0);

    self.tipBtn:addClickFuntion(self, self.onTipBtnClick);
    self.propBtn:addClickFuntion(self, self.onPropBtnClick);

    self:updateData();
end

function Lua_TacticFetterPanel:dispose()
    if self.dragContainer ~= nil then
        self.dragContainer:dispose();
        self.dragContainer = nil;
    end
    self:superCall("dispose");
end

function Lua_TacticFetterPanel:onScreenResize(adaptHeight)
    self:superCall("onScreenResize", adaptHeight);

    self.dragContainer:setContentRect(670, 1080 + adaptHeight);
end

function Lua_TacticFetterPanel:updateData()
    self.dragContainer:clearList();

    local arr = DataCenter.heroTacticData.getFetterArr;
    for i = 1, arr:getSize() do
        self.dragContainer:addSubContainer(Lua_TacticFetterItem, arr[i], false);
    end
    self.dragContainer:updateChildPos();

    if self.isFirstIn == nil then
        self.isFirstIn = false;
        local index = DataCenter.heroTacticData.getFetterUpIdx;
        self.dragContainer:moveToIndex(index, true)
    end
    
    DataCenter.redPointData:updateRedPointState(Lua_RedPointList.TacticFetter, DataCenter.heroTacticData.getFetterRedState);
end

function Lua_TacticFetterPanel:onTipBtnClick()
    local tipData = {des = LanUtil.getValue(792029), posX = -140, posY = -300};
    Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_TacticFetterPanel:onPropBtnClick()
    local arr = DataCenter.heroTacticData.totalFetterPropArr;
    if arr:getSize() > 0 then
        Lua_WindowUtil.openWin("Lua_TacticFetterPropWindow", Lua_WinParam.ACTION_OPEN, arr);
    else
        OperateAlert.showLangValue(792040);
    end
end


























Lua_TacticFetterItem = class("Lua_TacticFetterItem", Lua_DragContainerItem);

function Lua_TacticFetterItem:ctor(p)
    self:superCall("ctor", p, "TacticFetterItem_skin");
end

function Lua_TacticFetterItem:buildShowItem()
    self:superCall("buildShowItem");

    self.atlasItemArr = Array();
    self.propItemArr = Array();

    self.unLockBtn:addClickFuntion(self, self.onUnLockBtnClick);
end

function Lua_TacticFetterItem:dispose()
    if self.atlasItemArr ~= nil then
        self.atlasItemArr:dispose();
        self.atlasItemArr = nil;
    end
    if self.propItemArr ~= nil then
        self.propItemArr:dispose();
        self.propItemArr = nil;
    end
    if self.redPoint ~= nil then
        self.redPoint:dispose();
        self.redPoint = nil;
    end
    self.data = nil;
    self:superCall("dispose");
end

function Lua_TacticFetterItem:setData(id)
    self.data = DataCenter.heroTacticData:getFetterVo(id);

    self.nameTxt.text = self.data.name;

    local list = self.data.fight_rule_list;
    local len = list ~= nil and #list or 0;
    local num = self.atlasItemArr:getSize();
    local count = len > num and len or num;
    for i = 1, count do
        item = self.atlasItemArr[i];
        if item == nil then
            item = Lua_TacticAtlasItem.new(self.content);
            item:setLocation(-130 + (i - 1) % 2 * 260, 110 - Mathf.Floor((i - 1) / 2) * 250, 0);
            self.atlasItemArr:add(item);
        end

        if len >= i then
            item:setData(list[i]);
        end
        item:setEnable(len >= i);
    end

    local arr = DataCenter.heroTacticUtil:fetterPropVoArr(self.data.starLvId);
    len = arr:getSize();
    num = self.propItemArr:getSize();
    count = len > num and len or num;
    for i = 1, count do
        item = self.propItemArr[i];
        if item == nil then
            item = Lua_TacticAttributeItem.new(self.content, 4);
            item:setLocation(-220 + (i - 1) % 2 * 210, -65 - Mathf.Floor((i - 1) / 2) * 40, 0);
            self.propItemArr:add(item);
        end

        if len >= i then
            item:setData(arr[i]);
        end
        item:setEnable(len >= i);
    end

    local isMax = self.data.starLv >= self.data.max_level;
    if not isMax then
        if self.data.starLv < 0 then
            local nameStr = "";
            for i = 1, #list do
                local tacticVo = DataCenter.heroTacticData:getTacticVo(list[i]);
                if strIsNullOrEmpty(nameStr) then
                    nameStr = tacticVo.tacticName;
                else
                    nameStr = nameStr .. "、" .. tacticVo.tacticName;
                end
            end
            self.descTxt.text = LanUtil.formateStr(792030, nameStr);
            self.unLockBtn:setLangValue(792032);
        else
            self.descTxt.text = LanUtil.formateStr(792031, self.data.starLv + 1);
            self.unLockBtn:setLangValue(792033);
        end
    end
    self.descTxt:setEnable(not isMax);
    self.unLockBtn:setEnable(not isMax);
    self.maxDescTxt:setEnable(isMax);

    self:showRedPoint(self.data.state == 2)
end

function Lua_TacticFetterItem:getWidth()
    return 670;
end

function Lua_TacticFetterItem:getHeight()
    return 645;
end

function Lua_TacticFetterItem:onUnLockBtnClick()
    if self.data.state == 2 then
        local id = self.data.starLv < 0 and self.data.starLvId or self.data.starLvId + 1;
        Lua_ProxyManager.getProxy("Lua_HeroTacticProxy"):sTacticFetterUp(id);
    else
        OperateAlert.showLangValue(792034);
    end
end

function Lua_TacticFetterItem:showRedPoint(val)
    if val then
        if self.redPoint == nil then
            self.redPoint = Lua_RedPointIcon.new(self.content);
            self.redPoint:setLocation(80, -220, 0);
            self.redPoint:createRedPointEff();
        end
        self.redPoint:updateRedPointShow(true);
    else
        if self.redPoint ~= nil then
            self.redPoint:updateRedPointShow(false);
        end
    end
end






















Lua_TacticAtlasItem = class("Lua_TacticAtlasItem", Lua_DisplayObject);

function Lua_TacticAtlasItem:ctor(p)
    self:superCall("ctor", p, "TacticAtlasItem_skin");
end

function Lua_TacticAtlasItem:buildShowItem()
    self:superCall("buildShowItem");

    self.starArr = Array();

    self.bg:addClickFuntion(self, self.onBgClick);
end

function Lua_TacticAtlasItem:setData(tacticId)
    self.tacticId = tacticId;
    
    local tacticVo = DataCenter.heroTacticData:getTacticVo(tacticId);
    self.nameTxt.text = tacticVo.tacticName;
    self.bg:setAltas("hero_tactic_atlas", "xui_zf_widget_" .. (8 + tacticVo.color));
    self.bg:setGray(not tacticVo.isActive);
    self.showImg.url = tacticVo.atlas_img_path;
    self.showImg:setGray(not tacticVo.isActive);

    local len = tacticVo.isActive and tacticVo.tacticStar or 0;
    local num = self.starArr:getSize();
    local count = len > num and len or num;
    local item;
    local starWidth = 26;
    for i = 1, count do
        item = self.starArr[i];
        if item == nil then
            item = UICreate.createUIAtlasImage(self.content, "common_altas_1", "xui_common_label_09", 0, 0, 0, 0);
            self.starArr:add(item);
        end

        if len >= i then
            item:setLocation((i - 1) * starWidth - (len - 1) / 2 * starWidth, -77, 0);

        end
        item:setEnable(len >= i);
    end
    self.starBg:setEnable(len > 0);
end

function Lua_TacticAtlasItem:dispose()
    if self.starArr ~= nil then
        self.starArr:dispose();
        self.starArr = nil;
    end
    self:superCall("dispose");
end

function Lua_TacticAtlasItem:onBgClick()
    local tacticVo = DataCenter.heroTacticData:getTacticVo(self.tacticId);
    Lua_WindowUtil.openWin("Lua_TacticTipsWindow", Lua_WinParam.ACTION_OPEN, {data = tacticVo});
end