-- 战法升级 Panel
Lua_TacticIntensifyPanel = class("Lua_TacticIntensifyPanel", Lua_TacticDevelopBasePanel);

function Lua_TacticIntensifyPanel:ctor(p)
    self:superCall("ctor", p, "TacticIntensifyPanel_skin");
end

function Lua_TacticIntensifyPanel:buildPanel()
    self:superCall("buildPanel");
    self:addLuaEvent("UPDATE_TACTIC_INFO", self, self.updateData);
    self:addLuaEvent("UPDATE_TACTIC_UPGRADE_INFO", self, self.onShowEff);

    self:addLuaEvent("PACK_ITEMS_UPDATE", self, self.updateCostInfo);
    self:addLuaEvent("MONEY_UPDATE", self, self.updateCostInfo);
end

function Lua_TacticIntensifyPanel:buildShowItem()
    self:superCall("buildShowItem");

    self.propItemArr = Array();
    self.costTxtArr = Array();

    self.tipBtn:addClickFuntion(self, self.onTipBtnClick);
    self.resetBtn:addClickFuntion(self, self.onResetBtnClick);
    self.intensifyBtn:addClickFuntion(self, self.onIntensifyBtnClick);
end

function Lua_TacticIntensifyPanel:dispose()
    if self.propItemArr ~= nil then
        self.propItemArr:dispose();
        self.propItemArr = nil;
    end
    if self.costTxtArr ~= nil then
        self.costTxtArr:dispose();
        self.costTxtArr = nil;
    end
    if self.spineEff ~= nil then
        self.spineEff:dispose();
        self.spineEff = nil;
    end
    if self.showEff ~= nil then
        self.showEff:dispose();
        self.showEff = nil;
    end
    self.data = nil;
    self:superCall("dispose");
end

function Lua_TacticIntensifyPanel:setData(tacticId)
    self.tacticId = tacticId;
    self:updateData();
end

function Lua_TacticIntensifyPanel:updateData()
    self.data = DataCenter.heroTacticData:getTacticVo(self.tacticId);

    self.titleTxt.text = self.data.tacticName;
    self.resetBtn:setEnable(self.data.tacticLevel > self.data.min_level);

    if self.spineEff == nil then
        self.spineEff = UICreate.createUIEffect(self.content, self.data.effect_path, self.data.effect_name, 0, 0);
        self.spineEff.anchorValue = 1;
        self.spineEff.siblingIndex = 5;
    else
        self.spineEff:setUrl(self.data.effect_path, self.data.effect_name);
    end

    local scale = self.data.spine_scale;
    local offset = self.data.spine_offset;
    self.spineEff:setScale(scale, scale, scale);
    self.spineEff:setLocation(offset[1], -885 + offset[2]);

    local isMax = self.data.tacticLevel >= self.data.max_level;
    self.curLvTxt.text = self.data.tacticLevel;
    self.nextLvTxt.text = self.data.tacticLevel + 1
    if isMax then
        self.curLvIcon:setLocation(-46, 448, 0);
        self.curLvTxt:setLocation(41, 443, 0);
    else
        self.curLvIcon:setLocation(-174, 448, 0);
        self.curLvTxt:setLocation(-87, 443, 0);
    end
    self.arrawIcon:setEnable(not isMax);
    self.nextLvIcon:setEnable(not isMax);
    self.nextLvTxt:setEnable(not isMax);
    self.intensifyBtn:setEnable(not isMax);
    self.maxTxt:setEnable(isMax);

    local arr = DataCenter.heroTacticUtil:upgradeAttrVoArr(self.data.tacticLvlId);
    local len = arr:getSize();
    local num = self.propItemArr:getSize();
    local count = len > num and len or num;
    local item;
    for i = 1, count do
        item = self.propItemArr[i];
        if item == nil then
            item = Lua_TacticAttrCompareItem.new(self.content, 1);
            item:setRectAnchor(7);
            item:setLocation(0, 360 - (i - 1) * 55, 0);
            self.propItemArr:add(item);
        end

        if len >= i then
            item:setData(arr[i]);
        end
        item:setEnable(len >= i);
    end

    self:showStar(self.data.star, self.data.max_star);
    self:updateCostInfo();
end

function Lua_TacticIntensifyPanel:updateCostInfo()
    local list = DataCenter.heroTacticUtil:upgradeCost(self.data.tacticLvlId);
    self.noneCostId = DataCenter.packData:checkConsumeEnough(list);

    local len = list ~= nil and #list or 0;
    local num = self.costTxtArr:getSize();
    local count = len > num and len or num;
    local packNum;
    for i = 1, count do
        item = self.costTxtArr[i];
        if item == nil then
            item = UICreate.createLabel(self.content, nil, 0, 0, 100, 31, 24);
            item.anchorValue = 7;
            item.pivotValue = 4;
            item.alignmentValue = 4;
            item.horizontalOverflowValue = 1;
            item.verticalOverflowValue = 1;
            item.effectStyle = 2;
            item.effectColorStr = Lua_ColorDefine.transColor("000000");
            item:setEffectDistance(2, 2);
            self.costTxtArr:add(item);
        end

        if len >= i then
            packNum = DataCenter.packData:getItemCountById(list[i][1]);
            if packNum >= list[i][2] then
                item.text = LanUtil.formateStr(792015, spliceIconStrById(list[i][1]), numberTrans(packNum), list[i][2]);
            else
                item.text = LanUtil.formateStr(792016, spliceIconStrById(list[i][1]), numberTrans(packNum), list[i][2]);
            end
            item:setLocation((i - 1) * 250 - (len - 1) / 2 * 250, 230, 0);
        end
        item:setEnable(len >= i);
    end
    DataCenter.redPointData:updateRedPointState(Lua_RedPointList.TacticUpgrade, self.data.isUpgrade);
end

function Lua_TacticIntensifyPanel:onTipBtnClick()
    local tipData = {des = LanUtil.getValue(792017), posX = -140, posY = -300};
    Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_TacticIntensifyPanel:onResetBtnClick()
    Lua_WindowUtil.openWin("Lua_TacticResetWindow", Lua_WinParam.ACTION_OPEN, self.data);
end

function Lua_TacticIntensifyPanel:onIntensifyBtnClick()
    if self.noneCostId == nil then
        Lua_ProxyManager.getProxy("Lua_HeroTacticProxy"):sTacticUpgrade(self.data.unique_id);
    else
        DataCenter.packUtil:openPathWindow(self.noneCostId);
    end
end

function Lua_TacticIntensifyPanel:onShowEff()
    if self.showEff == nil then
        self.showEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_sb_shengji", "ui_sb_shengji", 0, -670);
        self.showEff.anchorValue = 1;
    else
        self.showEff:setEnable(false);
        self.showEff:setEnable(true);
    end
    self:updateData();
end