-- 战法Tips Window
checkRequire("Lua_TacticAttributeItem");
checkRequire("Lua_TacticSkillTagItem");
checkRequire("Lua_TacticSkillDescItem");
checkRequire("Lua_TacticSkillBuffItem");
Lua_TacticTipsWindow = class("Lua_TacticTipsWindow", Lua_Window);

function Lua_TacticTipsWindow:ctor()
    self:superCall("ctor");

    self.layer = Lua_MainWinDefine.TIPS_WINDOW_LAYER;
    self.showBlackMask = true;
    self.isClickClose = true;

    self.windowName = "Lua_TacticTipsWindow";
    self.skinName = "TacticTipsWindow_skin";
end

function Lua_TacticTipsWindow:buildPanel(go)
    self:superCall("buildPanel", go);
end

function Lua_TacticTipsWindow:buildShowItem()
    self:superCall("buildShowItem");

    self.dragContainer = Lua_DragContainer.new(self.show_obj, 460, 480, Lua_AxisDefine.Vertical);
    self.dragContainer:setRectPivot(1);
    self.dragContainer:setLocation(0, -195, 0);

    self.compoundBtn:addClickFuntion(self, self.onCompoundBtn);
end

function Lua_TacticTipsWindow:showWin(param)
    self:superCall("showWin", param);

    self.tacticVo = param.data;
    self.isShowBtns = param.isShowBtns;
    self.btnType = param.btnType;

    self.heroUid = param.heroUid;
    self.tacticUid = param.tacticUid;

    self:onShowInfo();
end

function Lua_TacticTipsWindow:dispose()
    if self.dragContainer ~= nil then
        self.dragContainer:dispose();
        self.dragContainer = nil;
    end
    if self._heroItem ~= nil then
        self._heroItem:dispose();
        self._heroItem = nil;
    end
    if self.redDotItem ~= nil then
        self.redDotItem:dispose();
        self.redDotItem = nil;
    end
    self.tacticVo = nil;
    self:superCall("dispose");
end

function Lua_TacticTipsWindow:onShowInfo()
    self.itemIcon:setData(self.tacticVo);
    self.itemIcon:setTacticLv(nil);
    self.itemIcon:setTacticWear(nil, nil);

    self.nameTxt.text = self.tacticVo.tacticColorName;
    self.levelTxt.text = LanUtil.formateStr(792000, self.tacticVo.tacticLevel, self.tacticVo.max_level);
    self.descTxt.text = self.tacticVo.desc;
    self.descTxt:resetSize();

    local state = self.tacticVo.tacticHeroUid > 0 and self.isShowBtns;
    if state then
        local heroVo = DataCenter.heroData:getItemByUniqueId(self.tacticVo.tacticHeroUid);
        if heroVo ~= nil then
            self.heroItem:setData(heroVo);

            if self.tacticVo.tacticAttachId > 0 then
                self.wearTxt.text = LanUtil.formateStr(792002, heroVo.name);
            else
                self.wearTxt.text = LanUtil.formateStr(792001, heroVo.name);
            end
        end
    else
        if self._heroItem ~= nil then
            self.heroItem:setEnable(false);
        end
    end
    self.wearBg:setEnable(state);
    self.wearTxt:setEnable(state);

    self.dragContainer:addSubContainer(Lua_TacticTipsPropItem, self.tacticVo, false, 20);
    self.dragContainer:addSubContainer(Lua_TacticTipsSkillItem, self.tacticVo, true, 20);

    local list = self.dragContainer.showDragDataList;
    local count = self.dragContainer.cellsCount;
    local addHeight = 0;
    for i = 1, count do
        addHeight = addHeight + list[i].cellHeight;
    end

    addHeight = addHeight < 480 and addHeight or 480;
    self.dragContainer:setContentRect(460, addHeight)
    self.dragContainer:moveToIndex(1, true);
    self.dragContainer.canDrag = not self.dragContainer.isTheEnd;

    addHeight = addHeight - 480;
    self.line2:setLocation(0, -686.4 - addHeight, 0);
    self.descTxt:setLocation(3.6, -707.5 - addHeight, 0);
    
    local height = self.descTxt.height - 30;
    if height > 0 then
        addHeight = addHeight + height;
    end

    state = not self.tacticVo.isActive;
    if state then
        local packNum = DataCenter.packData:getItemCountById(self.tacticVo.chipId);
        self.numTxt.text = LanUtil.formateStr(792003, packNum, self.tacticVo.activeNum);
        self.chipBar:setMaxValue(self.tacticVo.activeNum);
        self.chipBar:setValue(packNum);
        LuaUtil.setObjPos(self.chipObj, 0, 40 - addHeight, 0); 

        addHeight = addHeight + 125;
    end
    self.viewIcon:setEnable(state);
    self.chipObj:SetActive(state);

    local list;
    if self.tacticVo.isActive and self.isShowBtns then
        if self.btnType == 1 then -- 主战法选择
            list = {6}; -- 装备
        elseif self.btnType == 2 then -- 副战法选择
            if (self.heroUid > 0 and self.heroUid == self.tacticVo.tacticHeroUid) or self.tacticVo.tacticAttachId > 0 then
                list = {10}; -- 卸下
            else
                list = {13}; -- 附魂
            end
        elseif self.btnType == 3 then -- 背包
            if self.tacticVo.tacticHeroUid > 0 then
                list = {10, 11}; -- 卸下,养成
            else
                list = {6, 11}; -- 装备,养成
            end
        elseif self.btnType == 4 then -- 英雄界面
            list = {10, 11, 12}; -- 卸下,养成,替换
        end
        self:createButton(list, addHeight);

        addHeight = addHeight + 65;
    end

    self.winBg:SetDimensions(474, 767 + addHeight);
end

function Lua_TacticTipsWindow.Get:itemIcon()
    if self._itemIcon == nil then
        self._itemIcon = Lua_ItemIcon.new(self.show_obj);
        self._itemIcon:setLocation(-137, -93);
    end
    return self._itemIcon;
end

function Lua_TacticTipsWindow.Get:heroItem()
    if self._heroItem == nil then
        self._heroItem = Lua_ItemIcon.new(self.show_obj);
        self._heroItem:setScale(0.45, 0.45, 0.45);
        self._heroItem:setLocation(191, -132);
    end
    return self._heroItem;
end

function Lua_TacticTipsWindow:onCompoundBtn(go)
    local packNum = DataCenter.packData:getItemCountById(self.tacticVo.chipId);
    if packNum >= self.tacticVo.activeNum then
        Lua_ProxyManager.getProxy("Lua_PackProxy"):sSyntheticItem(self.tacticVo.chipId, 1);
        self:hide();
    else
        DataCenter.packUtil:openPathWindow(self.tacticVo.chipId, true);
    end
end

function Lua_TacticTipsWindow:createButton(list, addHeight)
    if self.btnArr == nil then
        self.btnArr = Array();
    end

    local len = #list;
    local num = self.btnArr:getSize();
    local count = len > num and len or num;
    local item;
    local nameStr;
    local btnWidth = 450 / len;
    for i = 1, count do
        item = self.btnArr[i];
        if item == nil then
            item = UICreate.createButton(self.show_obj, nil, 0, 0, 141, 54);
            item:setStyle(14);
            item.txt:setLocation(0, 0, 0);
            item.txt.fontSize = 28;
            item:addClickFuntion(self, self.onBtnClick);
            self.btnArr:add(item); 
        end

        if len >= i then
            nameStr = self:getBtnName(list[i]);
            item.label = nameStr;
            item.name = list[i];
            item:setLocation((i - 1) * btnWidth - (len - 1) / 2 * btnWidth, -775 - addHeight, 0);

            if self.btnType == 4 and list[i] == 11 then
                local state = DataCenter.heroTacticData:checkTacticRedDot(self.heroUid);
                self:showRedDot(state, (i - 1) * btnWidth - (len - 1) / 2 * btnWidth, -775 - addHeight);
            end
        end
        item:setEnable(len >= i);
    end
end

function Lua_TacticTipsWindow:getBtnName(t)
    if t == 6 then
        return LanUtil.getValue(792004); -- 装备
    elseif t == 10 then
        return LanUtil.getValue(792005); -- 卸下
    elseif t == 11 then
        return LanUtil.getValue(792006); -- 养成
    elseif t == 12 then
        return LanUtil.getValue(792007); -- 替换
    elseif t == 13 then
        return LanUtil.getValue(792008); -- 附魂
    end
    return "";
end

function Lua_TacticTipsWindow:onBtnClick(go)
    if tonumber(go.name) == 6 then
        if self.btnType == 3 then
            DataCenter.funcPathUtil:gotoFunction(1033, true);
        else
            if self.tacticVo.tacticHeroUid > 0 then
                local tipsData = {
                    des = LanUtil.getValue(792009),
                    btnType = 1,
                    owner = self,
                    sureFun = self.onSureWear
                };
                Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
            else
                self:onSureWear();
            end
            return;
        end
    elseif tonumber(go.name) == 10 then
        if self.tacticVo.tacticAttachId > 0 then
            Lua_ProxyManager.getProxy("Lua_HeroTacticProxy"):sTacticAttach(self.tacticVo.tacticAttachId);
        else
            Lua_ProxyManager.getProxy("Lua_HeroTacticProxy"):sTacticChange(self.tacticVo.unique_id);
        end
    elseif tonumber(go.name) == 11 then
        Lua_WindowUtil.openWin("Lua_TacticDevelopWindow", Lua_WinParam.ACTION_OPEN, {tacticId = self.tacticVo.id});
    elseif tonumber(go.name) == 12 then
        Lua_WindowUtil.openWin("Lua_TacticSelectWindow", Lua_WinParam.ACTION_OPEN, {selectType = 1, heroUid = self.heroUid, tacticUid = self.tacticVo.unique_id});
    elseif tonumber(go.name) == 13 then
        Lua_ProxyManager.getProxy("Lua_HeroTacticProxy"):sTacticAttach(self.tacticUid, self.tacticVo.unique_id);
    end
    self:hide();
end

function Lua_TacticTipsWindow:onSureWear()
    Lua_ProxyManager.getProxy("Lua_HeroTacticProxy"):sTacticChange(self.tacticVo.unique_id, self.heroUid);
    self:hide();
end

function Lua_TacticTipsWindow:showRedDot(val, btnPosX, btnPosY)
    if val then
        if self.redDotItem == nil then
            self.redDotItem = Lua_RedPointIcon.new(self.show_obj);
            self.redDotItem:createRedPointEff();
        end
        self.redDotItem:setLocation(btnPosX + 60, btnPosY + 20, 0);
        self.redDotItem:updateRedPointShow(true);
    else
        if self.redDotItem ~= nil then
            self.redDotItem:updateRedPointShow(false);
        end
    end
end




























Lua_TacticTipsPropItem = class("Lua_TacticTipsPropItem", Lua_DragContainerItem);

function Lua_TacticTipsPropItem:ctor(p)
    self:superCall("ctor", p, "TacticTipsPropItem_skin");
end

function Lua_TacticTipsPropItem:buildShowItem()
    self:superCall("buildShowItem");

    self.extendTxt:setLangValue(792041);

    self.itemArr = Array();
end

function Lua_TacticTipsPropItem:dispose()
    if self.itemArr ~= nil then
        self.itemArr:dispose();
        self.itemArr = nil;
    end
    self.data = nil;
    self:superCall("dispose");
end

function Lua_TacticTipsPropItem:setData(data)
    self.data = data;

    self.extendTxt:setEnable(data.tacticInheritId > 0);

    local arr = data.showPropArr;
    local len = arr:getSize();
    local num = self.itemArr:getSize();
    local count = len > num and len or num;
    local item;
    for i = 1, count do
        item = self.itemArr[i];
        if item == nil then
            item = Lua_TacticAttributeItem.new(self.content);
            item:setLocation(13 + (i - 1) % 2 * 215, -50 - math.floor((i - 1) / 2) * 50, 0);
            item:setRectAnchor(0);
            self.itemArr:add(item);
        end

        if len >= i then
            item:setData(arr[i]);
        end
        item:setEnable(len >= i);
    end
    self.addHeight = math.floor((len - 1) / 2) * 50 + 80;
end

function Lua_TacticTipsPropItem:getWidth()
    return 420;
end

function Lua_TacticTipsPropItem:getHeight()
    return self.addHeight;
end

























Lua_TacticTipsSkillItem = class("Lua_TacticTipsSkillItem", Lua_DragContainerItem);

function Lua_TacticTipsSkillItem:ctor(p)
    self:superCall("ctor", p, "TacticTipsSkillItem_skin");
end

function Lua_TacticTipsSkillItem:buildShowItem()
    self:superCall("buildShowItem");

    self.tagItemArr = Array();
    self.desItemArr = Array();
    self.buffItemArr = Array();
end

function Lua_TacticTipsSkillItem:dispose()
    if self.tagItemArr ~= nil then
        self.tagItemArr:dispose();
        self.tagItemArr = nil;
    end
    if self.desItemArr ~= nil then
        self.desItemArr:dispose();
        self.desItemArr = nil;
    end
    if self.buffItemArr ~= nil then
        self.buffItemArr:dispose();
        self.buffItemArr = nil;
    end
    self.data = nil;
    self:superCall("dispose");
end

function Lua_TacticTipsSkillItem:setData(data)
    self.data = data;

    local skillId = DataCenter.heroTacticUtil:getSkillId(data.tacticStarId);
    self.skillVo = Lua_SkillConfigData.getConfigData(skillId);
    self.skillicon:setAltas(self.skillVo.atlas, self.skillVo.sprite);
    self.nameTxt.text = self.skillVo.name;

    local list = self.skillVo.skill_tag;
    local len = list ~= nil and #list or 0;
    local num = self.tagItemArr:getSize();
    local count = len > num and len or num;
    local item;
    local offsetX = 0;
    for i = 1, count do
        item = self.tagItemArr[i];
        if item == nil then
            item = Lua_TacticSkillTagItem.new(self.content);
            item:setRectAnchor(0);
            self.tagItemArr:add(item);
        end

        if len >= i then
            item:setData(list[i]);
            item:setLocation(130 + offsetX, -95, 0);
            offsetX = offsetX + item:getWidth();
        end
        item:setEnable(len >= i);
    end

    list = self.skillVo.unlock_level_list;
    len = list ~= nil and #list or 0;
    num = self.desItemArr:getSize();
    count = len > num and len or num;
    local addHeight = 0;
    for i = 1, count do
        item = self.desItemArr[i];
        if item == nil then
            item = Lua_TacticSkillDescItem.new(self.content);
            item:setRectAnchor(0);
            item:setTxtWidth(420);
            self.desItemArr:add(item);
        end

        if len >= i then
            item:setData(self.skillVo["des" .. i], LanUtil.formateStr(792010, list[i]), data.tacticStar >= list[i]);
            item:setLocation(0, -135 - addHeight, 0);
            addHeight = addHeight + item:getHeight();
        end
        item:setEnable(len >= i);
    end

    list = self.skillVo.buff_list;
    len = list ~= nil and #list or 0;
    num = self.buffItemArr:getSize();
    count = len > num and len or num;
    for i = 1, count do
        item = self.buffItemArr[i];
        if item == nil then
            item = Lua_TacticSkillBuffItem.new(self.content);
            item:setRectAnchor(0);
            item:setTxtWidth(420);
            self.buffItemArr:add(item);
        end

        if len >= i then
            item:setData(list[i]);
            item:setLocation(0, -135 - addHeight, 0);
            addHeight = addHeight + item:getHeight();
        end
        item:setEnable(len >= i);
    end

    self.height = addHeight + 135;
end

function Lua_TacticTipsSkillItem:getWidth()
    return 420;
end

function Lua_TacticTipsSkillItem:getHeight()
    return self.height;
end