-- 战法升星 Panel
Lua_TacticUpStarPanel = class("Lua_TacticUpStarPanel", Lua_TacticDevelopBasePanel);

function Lua_TacticUpStarPanel:ctor(p)
    self:superCall("ctor", p, "TacticUpStarPanel_skin");
end

function Lua_TacticUpStarPanel:buildPanel()
    self:superCall("buildPanel");
    self:addLuaEvent("UPDATE_TACTIC_INFO", self, self.updateData);
    self:addLuaEvent("PACK_ITEMS_UPDATE", self, self.updateCostInfo);
end

function Lua_TacticUpStarPanel:buildShowItem()
    self:superCall("buildShowItem");

    self.propItemArr = Array();

    self.leftItem = Lua_TacticSkillIconItem.new(self.content);
    self.leftItem:setRectAnchor(7);
    self.leftItem:setLocation(-150, 528.5, 0);

    self.itemIcon = Lua_ItemIcon.new(self.content);
    self.itemIcon:setRectAnchor(7);
    self.itemIcon:setCanClick(true);
    self.itemIcon:setScale(0.8, 0.8, 0.8);
    self.itemIcon:setLocation(-268, 175, 0);

    self.tipBtn:addClickFuntion(self, self.onTipBtnClick);
    self.viewBtn:addClickFuntion(self, self.onViewBtnClick);
    self.upBtn:addClickFuntion(self, self.onUpBtnClick);
end

function Lua_TacticUpStarPanel:dispose()
    if self.propItemArr ~= nil then
        self.propItemArr:dispose();
        self.propItemArr = nil;
    end
    if self.leftItem ~= nil then
        self.leftItem:dispose();
        self.leftItem = nil;
    end
    if self.rightItem ~= nil then
        self.rightItem:dispose();
        self.rightItem = nil;
    end
    if self.spineEff ~= nil then
        self.spineEff:dispose();
        self.spineEff = nil;
    end
    self.data = nil;
    self:superCall("dispose");
end

function Lua_TacticUpStarPanel:setData(tacticId)
    self.tacticId = tacticId;
    self:updateData();
end

function Lua_TacticUpStarPanel:updateData()
    self.data = DataCenter.heroTacticData:getTacticVo(self.tacticId);

    self.titleTxt.text = self.data.tacticName;

    if self.spineEff == nil then
        self.spineEff = UICreate.createUIEffect(self.content, self.data.effect_path, self.data.effect_name, 0, 0);
        self.spineEff.anchorValue = 1;
        self.spineEff.siblingIndex = 5;
    else
        self.spineEff:setUrl(self.data.effect_path, self.data.effect_name);
    end

    local scale = self.data.spine_scale;
    local offset = self.data.spine_offset;
    self.spineEff:setScale(scale, scale, scale);
    self.spineEff:setLocation(offset[1], -885 + offset[2]);

    local arr = DataCenter.heroTacticUtil:upstarAttrVoArr(self.data.tacticStarId);
    local len = arr:getSize();
    local num = self.propItemArr:getSize();
    local count = len > num and len or num;
    local offsetY = len > 4 and (len - 4) * 40 or 0;
    local item;
    for i = 1, count do
        item = self.propItemArr[i];
        if item == nil then
            item = Lua_TacticAttrCompareItem.new(self.content, 2);
            item:setRectAnchor(7);
            self.propItemArr:add(item);
        end

        if len >= i then
            item:setData(arr[i]);
            item:setLocation(0, 420 - (i - 1) * 40 + offsetY, 0);
        end
        item:setEnable(len >= i);
    end

    self.attrBg:SetDimensions(720, 185 + offsetY);
    self.arrawIcon:setLocation(1.6, 528.5 + offsetY, 0);

    local skillId = DataCenter.heroTacticUtil:getSkillId(self.data.tacticStarId);
    self.leftItem:setData(skillId, self.data.tacticStar);

    local isMax = self.data.tacticStar >= self.data.max_star;
    if isMax then
        if self.rightItem ~= nil then
            self.rightItem:setEnable(false);
        end
        self.leftItem:setLocation(0, 528.5 + offsetY, 0);
    else
        if self.rightItem == nil then
            self.rightItem = Lua_TacticSkillIconItem.new(self.content);
            self.rightItem:setRectAnchor(7);
        end
        skillId = DataCenter.heroTacticUtil:getSkillId(self.data.tacticStarId + 1);
        self.rightItem:setData(skillId, self.data.tacticStar + 1);
        self.rightItem:setLocation(150, 528.5 + offsetY, 0);
        self.rightItem:setEnable(true);

        self.leftItem:setLocation(-150, 528.5 + offsetY, 0);
    end
    self.arrawIcon:setEnable(not isMax);
    self.itemIcon:setEnable(not isMax);
    self.numTxt:setEnable(not isMax);
    self.upBtn:setEnable(not isMax);
    self.maxTxt:setEnable(isMax);

    self:showStar(self.data.star, self.data.max_star);
    self:updateCostInfo();
end

function Lua_TacticUpStarPanel:updateCostInfo()
    if self.data.tacticStar < self.data.max_star then
        self.costInfo = DataCenter.heroTacticUtil:upstarCost(self.data.tacticStarId);
        if self.costInfo ~= nil then
            local itemVo = Lua_ToolVo.createToolVo(self.costInfo[1][1]);
            self.itemIcon:setData(itemVo);

            local packNum = DataCenter.packData:getItemCountById(self.costInfo[1][1]);
            if packNum >= self.costInfo[1][2] then
                self.numTxt.text = LanUtil.formateStr(792003, packNum, self.costInfo[1][2]);
            else
                self.numTxt.text = LanUtil.formateStr(792020, packNum, self.costInfo[1][2]);
            end
        end
    end
    DataCenter.redPointData:updateRedPointState(Lua_RedPointList.TacticUpstar, self.data.isUpstar);
end

function Lua_TacticUpStarPanel:onTipBtnClick()
    local tipData = {des = LanUtil.getValue(792021), posX = -140, posY = -300};
    Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_TacticUpStarPanel:onViewBtnClick()
    Lua_WindowUtil.openWin("Lua_TacticStarViewWindow", Lua_WinParam.ACTION_OPEN, self.data);
end

function Lua_TacticUpStarPanel:onUpBtnClick()
    if self.costInfo == nil then
        return;
    end

    local costId = DataCenter.packData:checkConsumeEnough(self.costInfo);
    if costId ~= nil then
        DataCenter.packUtil:openPathWindow(costId);
        return;
    end
    Lua_ProxyManager.getProxy("Lua_HeroTacticProxy"):sTacticUpStar(self.data.unique_id);
end