--战技领悟
Lua_TalentStudyPanel = class("Lua_TalentStudyPanel", Lua_DisplayObject);
function Lua_TalentStudyPanel:ctor(p)
    self:superCall("ctor", p,"TalentStudyPanel_skin");
end

function Lua_TalentStudyPanel:buildShowItem()
    self:superCall("buildShowItem");

    self:addLuaEvent("ON_SELECT_TALENT_STUDY", self, self.selectTalent);

    self.itemIcon = Lua_ItemIcon.new(self.content);
    self.itemIcon:setLocation(-126, -318, 0);
    self.itemIcon:setCanClick(true);

    self.dragList = Lua_DragList.new(self.content,634, 363, Lua_AxisDefine.Vertical);
    self.dragList:setListCell(Lua_TalentStudyCell, 114, 140, 5);
    self.dragList:setCellSpacing(16, 7);
    self.dragList:setLocation(0, -50);

    self.study_btn:addClickFuntion(self, self.onStudyBtnClick);
    self.skill_icon:addClickFuntion(self, self.onSkillBtnClick);
end

function Lua_TalentStudyPanel:updateShowInfo(param)
    self.showData = param;
    self.part = param.part;
    self.hvo = param.hvo;
    self.hero_uid = param.hvo.unique_id;

    local arr = DataCenter.talentData:getTalentStudyInfo(1, param.hvo.talent_list);
    self.dragList:setArrayData(arr);
    self.dragList:setSelected(1);
    self:selectTalent(arr[1]);
end

function Lua_TalentStudyPanel:selectTalent(data)
    self.talent_id = data.id;
    self.talent_data = Lua_TalentConfigData.getConfigData(self.talent_id);

    local skill_vo = self.talent_data.skill_vo;
    self.skill_icon:setAltas(skill_vo.atlas, skill_vo.sprite);
    self.skill_name.text = skill_vo.name;
    self.skill_des.text = skill_vo.des;

    self.id = self.talent_data.study_cost[1][1];
    local tvo = Lua_ToolVo.new(self.id);
    self.itemIcon:setData(tvo);

    self.item_name.text = tvo.name;
    self.have_num = DataCenter.packData:getItemCountById(self.id); 
    self.need_num = self.talent_data.study_cost[1][2];

    local str = numberTrans(self.have_num);
    if self.have_num < self.need_num then
        str = Lua_ColorDefine.getColorStr("da1f1f",str);
    end
    self.item_num.text =str.."/"..numberTrans(self.need_num);
end

--战技学习
function Lua_TalentStudyPanel:onStudyBtnClick()
    local list = self.hvo.talent_info;
    for i=1,#list do
        if tonumber(list[i].value) ~= 0 then
            local _type = Lua_TalentConfigData.getConfigData(tonumber(list[i].value)).type;
            if _type == self.talent_data.type then
                OperateAlert.showLangValue(126862);
                return;
            end
        end
    end

    if self.have_num < self.need_num then
        DataCenter.packUtil:openPathWindow(self.id, false);
        return;
    end

    Lua_ProxyManager.getProxy("Lua_TalentProxy"):sTalentStudy(self.hero_uid, self.part, self.talent_id, 1);
    Lua_WindowUtil.openWin("Lua_TalentStudyWindow", Lua_WinParam.ACTION_CLOSE);
end

--技能tips
function Lua_TalentStudyPanel:onSkillBtnClick()
    if self.talent_data.skill_vo ~= nil then
        Lua_WindowUtil.openWin("Lua_SkillTipsWindow", Lua_WinParam.ACTION_OPEN, self.talent_data.skill_vo);
    end
end

function Lua_TalentStudyPanel:dispose()
    if self.dragList == nil then
        self.dragList:dispose();
        self.dragList = nil;
    end
    self.showData = nil;
    self:superCall("dispose");
end

















Lua_TalentStudyCell = class("Lua_TalentStudyCell", Lua_ListCell);
function Lua_TalentStudyCell:ctor(p)
    self:superCall("ctor", p, "TalentStudyCell_skin");
end

function Lua_TalentStudyCell:buildShowItem()
    self:superCall("buildShowItem");
    self.select_bg:setEnable(false);
end

function Lua_TalentStudyCell:setData(data)
    self.data = data;
    
    local id = data.id;
    local talent_data  = Lua_TalentConfigData.getConfigData(id);
    local skill_vo = talent_data.skill_vo;
    if skill_vo ~= nil then
        self.skill_icon:setAltas(skill_vo.atlas, skill_vo.sprite);
    end
    self.skill_name.text = talent_data.name;

    if data.isStudy then
        self.study_spr:setEnable(true);
        self.study_spr:setAltas("hero_atlas_3","ui_zj_label_01");
    elseif data.isRecommend then
        self.study_spr:setEnable(true);
        self.study_spr:setAltas("hero_atlas_3","ui_zj_label_02");
    else
        self.study_spr:setEnable(false);
    end

    self:updateSelect()
end

function Lua_TalentStudyCell:updateSelect()
    self.select_bg:setEnable(self.data.isSelect);
end

function Lua_TalentStudyCell:onPressClick()
    Lua_MsgUtil.callFunc("ON_SELECT_TALENT_STUDY", self.data);
    return true;
end

function Lua_TalentStudyCell:onSelectionChange(bSelect)
    self:superCall("onSelectionChange", bSelect);
    self.data.isSelect = bSelect;
    self:updateSelect();
end

function Lua_TalentStudyCell:dispose()
    self.data = nil;
    if self.itemIcon ~= nil then
        self.itemIcon:dispose();
        self.itemIcon = nil;
    end
    self:superCall("dispose");
end